@@ -77,13 +77,35 @@ def test_every_umc_server_has_a_saml_client(ucr, keycloak_config):
         assert f'https://{host}/univention/saml/metadata' in kc_clients
 
 
-def test_list_users_works(keycloak_config):
-    """See https://forge.univention.org/bugzilla/show_bug.cgi?id=57205"""
-    # check that there is an object with objectclass=person but without uid
-    ldap = get_ldap_connection()
-    assert ldap.search('(&(objectclass=person)(!(uid=*)))')
-    assert keycloak_get_request(keycloak_config, 'realms/master/users')
-    assert keycloak_get_request(keycloak_config, 'realms/ucs/users')
+@pytest.mark.parametrize('realm', ['master', 'ucs'])
+def test_rest_api_endpoints(keycloak_config, realm: str):
+    """
+    Test some of the REST endpoints
+
+    In the past we made changes that broke the user list request,
+    test some of the endpoints here to make sure they work
+
+    See https://forge.univention.org/bugzilla/show_bug.cgi?id=57205
+    """
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users/profile')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users')
+    users = keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/brute-force-user')
+    assert users
+    some_user_id = users[0]['id']
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users/{some_user_id}?userProfileMetadata=true')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/clients')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/client-scopes')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/roles')
+    keycloak_get_request(keycloak_config, f'realms/{realm}/groups')
+    keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/sessions')
+    keycloak_get_request(keycloak_config, f'realms/{realm}/admin-events')
+    keycloak_get_request(keycloak_config, f'realms/{realm}/events')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/unregistered-required-actions')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/required-actions')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/flows')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/authentication-management/flows')
+    assert keycloak_get_request(keycloak_config, f'realms/{realm}/components')
 
 
 def test_master_realm_config(keycloak_config, ucr):
